#
# spec file for package python-truststore
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-truststore
Version:        0.10.0
Release:        1.1
Summary:        Verify certificates using OS trust stores
License:        MIT
URL:            https://github.com/sethmlarson/truststore
Source:         https://github.com/sethmlarson/truststore/archive/refs/tags/v%{version}.tar.gz#/truststore-%{version}.tar.gz
BuildRequires:  %{python_module aiohttp}
BuildRequires:  %{python_module flaky}
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module httpx}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pyOpenSSL}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest-httpserver}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module trustme}
BuildRequires:  %{python_module urllib3}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Verify certificates using OS trust stores. Supports macOS,
Windows, and Linux (with OpenSSL). This project should be
considered experimental.

%prep
%autosetup -p1 -n truststore-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -s -k 'not internet and not test_wrong_host_succeeds_with_hostname_verification_disabled'

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/truststore
%{python_sitelib}/truststore-%{version}.dist-info

%changelog
* Tue Jan 28 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.10.0
  * Added support for macOS 10.13 and earlier using the `SecTrustEvaluate`
    API. Note that this API doesn't return fine-grained errors like
    `SecTrustEvaluateWithError` (requires macOS 10.14+).
  * Added `SSLContext.set_default_verify_paths()` method.
  * Changed method for disabling hostname verification for macOS and
    Windows. Previously would ignore hostname verification errors if
    `SSLContext.check_hostname` was `False`.
    Now for both macOS and Windows the certificate verification policy
    is configured to not check certificate hostname. This should have
    no effect on users.
- from version 0.9.2
  * Fixed an issue where implementations supporting Python 3.10 but not
    the peer certificate chain APIs would fail during the handshake instead
    of when importing the `truststore` module. The module now raises an error
    immediately instead of on first handshake. This was added for the GraalPy
    implementation specifically, but there may be others.
- Skip test_wrong_host_succeeds_with_hostname_verification_disabled test
* Thu Oct  3 2024 Steve Kowalik <steven.kowalik@suse.com>
- Add missing BuildRequires on pyOpenSSL for the testsuite, rather than
  depending on it transitivity.
* Wed Aug 14 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.9.1:
  * Fixed an issue for CPython 3.13 where `ssl.SSLSocket` and `ssl.SSLObject`
    certificate chain APIs would return different types.
  * Added support for Python 3.13.
  * Fixed loading additional certificates on macOS.
- Drop patch no-network-testing.patch, not required.
* Sat Mar  2 2024 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Fri Sep 29 2023 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.8.0
- refresh no-network-testing.patch
  * Added documentation for how to use truststore with urllib3,
  Requests, aiohttp, and pip.
  * Added pass-through implementations for many ssl.SSLContext methods
  like load_cert_chain(), set_alpn_protocols(), etc.
  * Added inject_into_ssl() and extract_from_ssl() to enable Truststore
  for all packages using ssl.SSLContext automatically
  * Added support for setting check_hostname, verify_mode, and verify_flags.
  * Fixed issue where a RecursionError that would be raised when setting
  SSLContext.minimum_version or .maximum_version
* Thu Jul 28 2022 Matej Cepl <mcepl@suse.com>
- Initial packaging effort for truststore 0.4.0.
- Add no-network-testing.patch to skip networked tests
  (gh#sethmlarson/truststore#65).
